@@ -2,7 +2,11 @@ from functools import wraps
 from typing import Callable
 
 from flask import current_app, jsonify
-from flask_apispec import doc
+from flask_smorest import Blueprint
+from flask_smorest.arguments import ArgumentsMixin
+from flask_smorest.response import ResponseMixin
+from flask_smorest.pagination import PaginationMixin
+from flask_smorest.etag import EtagMixin
 from flask_jwt_extended import verify_jwt_in_request
 from flask_jwt_extended.utils import get_jwt_claims
 
@@ -31,17 +35,48 @@ def http_code(func: Callable) -> Callable:
     return wrapper
 
 
-def api_doc(**kwds) -> Callable:
+def api_doc(*args, **kwds) -> Callable:
     """
-    Decorator for adding API documentation through the documentation in the view function.
+    See here https://flask-smorest.readthedocs.io/en/latest/api_reference.html#flask_smorest.Blueprint.doc
     """
 
-    def wrapper(func: Callable):
-        d = kwds.pop("description", func.__doc__ or "")
-        kwds["description"] = d
-        func = doc(**kwds)(func)
-        return func
+    wrapper = Blueprint.doc(*args, **kwds)
+    return wrapper
 
+
+def use_kwargs(*args, **kwds) -> Callable:
+    """
+    See here https://flask-smorest.readthedocs.io/en/latest/arguments.html
+    """
+
+    wrapper = ArgumentsMixin().arguments(*args, **kwds)
+    return wrapper
+
+
+def marshal_with(*args, **kwds) -> Callable:
+    """
+    See here https://flask-smorest.readthedocs.io/en/latest/response.html#
+    """
+
+    wrapper = ResponseMixin().alt_response(*args, **kwds)
+    return wrapper
+
+
+def paginate(*args, **kwds) -> Callable:
+    """
+    See here https://flask-smorest.readthedocs.io/en/latest/pagination.html.
+    """
+
+    wrapper = PaginationMixin().paginate(*args, **kwds)
+    return wrapper
+
+
+def etag(schema=None) -> Callable:
+    """
+    See here https://flask-smorest.readthedocs.io/en/latest/etag.html
+    """
+
+    wrapper = EtagMixin().etag(schema)
     return wrapper
 
 
@@ -85,7 +120,7 @@ def authenticate(roles={}) -> Callable:
     """
 
     def decorated(func: Callable) -> Callable:
-        func = api_doc(security=current_app.config.get("APISPEC_SECURITY_PARAMS", []))(
+        func = api_doc(security=current_app.config.get("API_SECURITY_PARAMS", []))(
             jwt_required(roles)(func)
         )
         return func
